@@ -4,7 +4,7 @@ package App::SFDC::Deploy;
 use strict;
 use warnings;
 
-our $VERSION = '0.06'; # TRIAL VERSION
+our $VERSION = '0.08'; # TRIAL VERSION
 
 use Data::Dumper;
 use File::Find 'find';
@@ -72,6 +72,12 @@ option 'runtests',
     default => 0;
 
 
+option 'testoutput',
+    format => 's',
+    short => 'o',
+    is => 'ro';
+
+
 option 'validate',
     is => 'ro',
     short => 'v',
@@ -121,6 +127,16 @@ has '_result',
         );
     };
 
+sub _JUnitOutput {
+    my $self = shift;
+    return unless $self->testoutput;
+    Role::Tiny->apply_roles_to_object(
+        $self->_result,
+        'App::SFDC::Role::DeployResult::JUnitOutput'
+    );
+    $self->_result->printToJUnit($self->testoutput);
+}
+
 
 sub execute {
     my $self = shift;
@@ -129,6 +145,7 @@ sub execute {
         return;
     }
     print $self->_result;
+    $self->_JUnitOutput;
     return $self->_result->success;
 }
 
@@ -144,7 +161,7 @@ App::SFDC::Deploy - Deploy files to SFDC
 
 =head1 VERSION
 
-version 0.06
+version 0.08
 
 =head1 OPTIONS
 
@@ -178,6 +195,11 @@ Whether or not to send the 'rollbackonerror' header. Defaults to true.
 If set, set 'testLevel' to 'RunLocalTests', i.e. run all tests in your own
 namespace. This has no effect on Production, and doesn't work before API v34.0
 
+=head2 --testoutput -o
+
+If set, then this file will be populated with JUnit-formatted xml containing
+the test results of this deployment.
+
 =head2 --validate -v
 
 If set, set 'isCheckOnly' to true, i.e. perform a validation deployment.
