@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use 5.10.0;
 
-our $VERSION = '0.06'; # TRIAL VERSION
+our $VERSION = '0.08'; # TRIAL VERSION
 
 use App::SFDC;
 
@@ -28,7 +28,7 @@ sub usage {"
 # expect @ARGV to start with an operation which would be invalid as input to
 # GetOptions, which is why we shift instead of using $_[0]
 
-local $_ = shift;
+local $_ = shift || '';
 exit not do {
     if (/retrieve/i) {
         App::SFDC::Retrieve->new_with_options->execute();
@@ -49,7 +49,7 @@ SFDC - Command tool for interacting with Salesforce.com
 
 =head1 VERSION
 
-version 0.06
+version 0.08
 
 =head1 DESCRIPTION
 
